@@ -5,6 +5,7 @@ use crate::{
     cluster_slots::ClusterSlots,
     outstanding_requests::OutstandingRequests,
     repair_weight::RepairWeight,
+    replay_stage::DUPLICATE_THRESHOLD,
     result::Result,
     serve_repair::{RepairType, ServeRepair},
 };
@@ -15,10 +16,13 @@ use solana_ledger::{
     shred::Nonce,
 };
 use solana_measure::measure::Measure;
-use solana_runtime::{
-    bank::Bank, bank_forks::BankForks, commitment::VOTE_THRESHOLD_SIZE, contains::Contains,
+use solana_runtime::{bank::Bank, bank_forks::BankForks, contains::Contains};
+use solana_sdk::{
+    clock::{BankId, Slot},
+    epoch_schedule::EpochSchedule,
+    pubkey::Pubkey,
+    timing::timestamp,
 };
-use solana_sdk::{clock::Slot, epoch_schedule::EpochSchedule, pubkey::Pubkey, timing::timestamp};
 use std::{
     collections::{HashMap, HashSet},
     iter::Iterator,
@@ -33,6 +37,8 @@ use std::{
 
 pub type DuplicateSlotsResetSender = CrossbeamSender<Slot>;
 pub type DuplicateSlotsResetReceiver = CrossbeamReceiver<Slot>;
+pub type ConfirmedSlotsSender = CrossbeamSender<Vec<Slot>>;
+pub type ConfirmedSlotsReceiver = CrossbeamReceiver<Vec<Slot>>;
 
 pub type OutstandingRepairs = OutstandingRequests<RepairType>;
 
@@ -223,7 +229,7 @@ impl RepairService {
 
                 add_votes_elapsed = Measure::start("add_votes");
                 repair_weight.add_votes(
-                    &blockstore,
+                    blockstore,
                     slot_to_vote_pubkeys.into_iter(),
                     root_bank.epoch_stakes_map(),
                     root_bank.epoch_schedule(),
@@ -271,7 +277,7 @@ impl RepairService {
             let mut outstanding_requests = outstanding_requests.write().unwrap();
             repairs.into_iter().for_each(|repair_request| {
                 if let Ok((to, req)) = serve_repair.repair_request(
-                    &cluster_slots,
+                    cluster_slots,
                     repair_request,
                     &mut cache,
                     &mut repair_stats,
@@ -487,7 +493,7 @@ impl RepairService {
                 repair_validators,
             );
             if let Some((repair_pubkey, repair_addr)) = status.repair_pubkey_and_addr {
-                let repairs = Self::generate_duplicate_repairs_for_slot(&blockstore, *slot);
+                let repairs = Self::generate_duplicate_repairs_for_slot(blockstore, *slot);
 
                 if let Some(repairs) = repairs {
                     let mut outstanding_requests = outstanding_requests.write().unwrap();
@@ -529,7 +535,7 @@ impl RepairService {
         nonce: Nonce,
     ) -> Result<()> {
         let req =
-            serve_repair.map_repair_request(&repair_type, repair_pubkey, repair_stats, nonce)?;
+            serve_repair.map_repair_request(repair_type, repair_pubkey, repair_stats, nonce)?;
         repair_socket.send_to(&req, to)?;
         Ok(())
     }
@@ -558,7 +564,7 @@ impl RepairService {
 
     #[allow(dead_code)]
     fn process_new_duplicate_slots(
-        new_duplicate_slots: &[Slot],
+        new_duplicate_slots: &[(Slot, BankId)],
         duplicate_slot_repair_statuses: &mut HashMap<Slot, DuplicateSlotRepairStatus>,
         cluster_slots: &ClusterSlots,
         root_bank: &Bank,
@@ -567,16 +573,16 @@ impl RepairService {
         duplicate_slots_reset_sender: &DuplicateSlotsResetSender,
         repair_validators: &Option<HashSet<Pubkey>>,
     ) {
-        for slot in new_duplicate_slots {
+        for (slot, bank_id) in new_duplicate_slots {
             warn!(
-                "Cluster completed slot: {}, dumping our current version and repairing",
+                "Cluster confirmed slot: {}, dumping our current version and repairing",
                 slot
             );
             // Clear the slot signatures from status cache for this slot
             root_bank.clear_slot_signatures(*slot);
 
             // Clear the accounts for this slot
-            root_bank.remove_unrooted_slot(*slot);
+            root_bank.remove_unrooted_slots(&[(*slot, *bank_id)]);
 
             // Clear the slot-related data in blockstore. This will:
             // 1) Clear old shreds allowing new ones to be inserted
@@ -641,7 +647,7 @@ impl RepairService {
                                 })
                                 .sum();
                             if total_completed_slot_stake as f64 / total_stake as f64
-                                > VOTE_THRESHOLD_SIZE
+                                > DUPLICATE_THRESHOLD
                             {
                                 Some(dead_slot)
                             } else {
@@ -1059,7 +1065,7 @@ mod test {
         let serve_repair = ServeRepair::new(cluster_info.clone());
         let valid_repair_peer = Node::new_localhost().info;
 
-        // Signal that this peer has completed the dead slot, and is thus
+        // Signal that this peer has confirmed the dead slot, and is thus
         // a valid target for repair
         let dead_slot = 9;
         let cluster_slots = ClusterSlots::default();
@@ -1138,6 +1144,7 @@ mod test {
         );
         let bank0 = Arc::new(Bank::new(&genesis_config));
         let bank9 = Bank::new_from_parent(&bank0, &Pubkey::default(), duplicate_slot);
+        let duplicate_bank_id = bank9.bank_id();
         let old_balance = bank9.get_balance(&keypairs.node_keypair.pubkey());
         bank9
             .transfer(10_000, &mint_keypair, &keypairs.node_keypair.pubkey())
@@ -1155,7 +1162,7 @@ mod test {
         assert!(bank9.get_signature_status(&vote_tx.signatures[0]).is_some());
 
         RepairService::process_new_duplicate_slots(
-            &[duplicate_slot],
+            &[(duplicate_slot, duplicate_bank_id)],
             &mut duplicate_slot_repair_statuses,
             &cluster_slots,
             &bank9,
